@@ -1,11 +1,10 @@
 from macholib import mach_o
 
-import unittest
-
-try:
-    expectedFailure = unittest.expectedFailure
-except AttributeError:
-    expectedFailure = lambda function: function
+import sys
+if sys.version_info[:2] <= (2,6):
+    import unittest2 as unittest
+else:
+    import unittest
 
 
 class TestMachO (unittest.TestCase):
